==> acornlib-1.21.1-r7-sources.jar: net/acoyt/acornlib/impl/util/AcornLibUtils.java <==
package net.acoyt.acornlib.impl.util;

import net.acoyt.acornlib.impl.AcornLib;
import net.minecraft.class_2561;
import java.time.LocalDate;
import java.util.UUID;

import static net.acoyt.acornlib.impl.AcornLib.supporters;

@SuppressWarnings("unused")
public class AcornLibUtils {
    // Birthday
    private static final LocalDate today = LocalDate.now();
    public static final boolean isAcoBirthday = LocalDate.of(today.getYear(), 9, 12).compareTo(today) * today.compareTo(LocalDate.of(today.getYear(), 9, 12)) >= 0;
    public static final boolean isAprilFools = LocalDate.of(today.getYear(), 4, 1).compareTo(today) * today.compareTo(LocalDate.of(today.getYear(), 4, 1)) >= 0;

    // Aco Utils
    public static class_2561 acoName = class_2561.method_43470("AcoYT");
    public static UUID acoUuid = UUID.fromString("017f5cdc-086b-4d98-a0c2-7dc43d5117bd");

    // Fried Stuff
    public static int friendColor = 0x13515d;
    public static int supporterColor = 0x8e010c;
    public static int bothColor = 0x9e58f7;
    public static int blacklistedColor = 0x6e070d;

    public static class_2561 stylizeNames(UUID uuid, class_2561 text) {
        boolean bl = AcornLib.isSupporter(uuid) || AcornLib.isBlacklisted(uuid);
        int color;

        if (supporters.isFriend(uuid) && !supporters.isSupporter(uuid)) {
            color = friendColor;
        } else if (supporters.isFriend(uuid) && supporters.isSupporter(uuid)) {
            color = bothColor;
        } else if (!supporters.isFriend(uuid) && supporters.isSupporter(uuid)) {
            color = supporterColor;
        } else if (supporters.isBlacklisted(uuid)) {
            color = blacklistedColor;
        } else {
            color = 0xFFFFFF;
        }

        return bl ? text.method_27661().method_27694(style -> style.method_36139(color)) : text;
    }

    public static int convertToHex(String hexString) {
        hexString = hexString.replace("#", ""); // Remove # if present
        return Integer.parseInt(hexString, 16); // Convert to an int
    }
}

==> acornlib-1.21.8-r5-sources.jar: net/acoyt/acornlib/impl/util/AcornLibUtils.java <==
package net.acoyt.acornlib.impl.util;

import net.acoyt.acornlib.impl.AcornLib;
import net.minecraft.class_2561;
import java.time.LocalDate;
import java.util.UUID;

import static net.acoyt.acornlib.impl.AcornLib.supporters;

@SuppressWarnings("unused")
public class AcornLibUtils {
    // Birthday
    private static final LocalDate today = LocalDate.now();
    public static final boolean isAcoBirthday = LocalDate.of(today.getYear(), 9, 12).compareTo(today) * today.compareTo(LocalDate.of(today.getYear(), 9, 12)) >= 0;
    public static final boolean isAprilFools = LocalDate.of(today.getYear(), 4, 1).compareTo(today) * today.compareTo(LocalDate.of(today.getYear(), 4, 1)) >= 0;

    // Aco Utils
    public static class_2561 acoName = class_2561.method_43470("AcoYT");
    public static UUID acoUuid = UUID.fromString("017f5cdc-086b-4d98-a0c2-7dc43d5117bd");

    // Fried Stuff
    public static int friendColor = 0x13515d;
    public static int supporterColor = 0x8e010c;
    public static int bothColor = 0x9e58f7;

    public static class_2561 stylizeNames(UUID uuid, class_2561 text) {
        boolean bl = AcornLib.isSupporter(uuid);
        int color;

        if (supporters.isFriend(uuid) && !supporters.isSupporter(uuid)) {
            color = friendColor;
        } else if (supporters.isFriend(uuid) && supporters.isSupporter(uuid)) {
            color = bothColor;
        } else if (!supporters.isFriend(uuid) && supporters.isSupporter(uuid)) {
            color = supporterColor;
        } else {
            color = 0xFFFFFF;
        }

        return bl ? text.method_27661().method_27694(style -> style.method_36139(color)) : text;
    }

    public static int convertToHex(String hexString) {
        hexString = hexString.replace("#", ""); // Remove # if present
        return Integer.parseInt(hexString, 16); // Convert to an int
    }
}
